@@ -99,9 +99,9 @@ MainWindow::MainWindow(QWidget *parent) :
         ui->txtAwayTeam->setStyle(new QPlastiqueStyle);
         ui->twGames->setStyle(new QPlastiqueStyle);
         ui->twStandings->setStyle(new QPlastiqueStyle);
-        ui->cbRounds->setStyle(new QPlastiqueStyle);
-        ui->cbTeam->setStyle(new QPlastiqueStyle);
-        ui->cbSeason->setStyle(new QPlastiqueStyle);
+//        ui->cbRounds->setStyle(new QPlastiqueStyle);
+//        ui->cbTeam->setStyle(new QPlastiqueStyle);
+//        ui->cbSeason->setStyle(new QPlastiqueStyle);
         ui->webView->setProperty("FingerScrollable", true);
         ui->webView_OnlineTable->setProperty("FingerScrollable", true);
         ui->webView_UpdateScores->setProperty("FingerScrollable", true);
@@ -529,9 +529,9 @@ void MainWindow::showURL()
   //      sXMLFile = QDir::currentPath().append(QDir::separator()).append("rss.xml");
     //    sHTMLFile = QDir::currentPath().append(QDir::separator()).append("tmp.html");
 
-        sXSLTPath = "/Allway Sync/mobitifo-0.0.1/data/rss.xsl";
-        sXMLFile = "/Allway Sync/mobitifo-0.0.1/data/rss.xml";
-        sHTMLFile = "/Allway Sync/mobitifo-0.0.1/data/tmp.html";
+        sXSLTPath = "/Allway Sync/mobitifo-0.0.2/data/rss.xsl";
+        sXMLFile = "/Allway Sync/mobitifo-0.0.2/data/rss.xml";
+        sHTMLFile = "/Allway Sync/mobitifo-0.0.2/data/tmp.html";
 
         // NOTE: File exists in the application private folder, in Symbian Qt implementation
 #endif
@@ -620,7 +620,7 @@ bool MainWindow::existDatabase()
         path = QDir::toNativeSeparators(path);
 #else
         //path = "./mobitifo.db" ;
-        path = "/Allway Sync/mobitifo-0.0.1/data/mobitifo.db" ;
+        path = "/Allway Sync/mobitifo-0.0.2/data/mobitifo.db" ;
         // NOTE: File exists in the application private folder, in Symbian Qt implementation
 #endif
         fDbFile.setFileName(path);
@@ -1131,7 +1131,15 @@ int MainWindow::getMaxPlayedRound(int iSelectedEventID)
         iMaxRound = qry.value(0).toInt();
         qDebug() << iMaxRound;
     }
-    sSelectedRound = QString::number(iMaxRound);
+    if (iMaxRound >0)
+    {
+        sSelectedRound = QString::number(iMaxRound);
+    }
+    else
+    {
+        sSelectedRound = "1";
+    }
+
     return iMaxRound;
 }
 
@@ -1756,7 +1764,7 @@ void MainWindow::showAbout()
     message.append("MobiTifo");
     message.append("-");
 //    version = version.setNum(APP_VERSION);
-    version = "0.0.1";
+    version = "0.0.2";
     message.append(version);
     message.append("\n by ");
 //    message.append(AUTHOR);
